intelmq.bots.parsers.json package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.json package

## Submodules

## intelmq.bots.parsers.json.parser module

JSON Parser Bot Retrieves a base64 encoded JSON-String from raw and converts it into an event.

Copyright (C) 2016 by Bundesamt für Sicherheit in der Informationstechnik Software engineering by Intevation GmbH

`intelmq.bots.parsers.json.parser.` `BOT`

  alias of `intelmq.bots.parsers.json.parser.JSONParserBot`

class `intelmq.bots.parsers.json.parser.` `JSONParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse IntelMQ-JSON data

  `process`()
  `splitlines` = False

## Module contents